Class WebSecurityScannerClient

java.lang.Object
com.google.cloud.websecurityscanner.v1.WebSecurityScannerClient
All Implemented Interfaces:
BackgroundResource, AutoCloseable

@Generated("by gapic-generator-java") public class WebSecurityScannerClient extends Object implements BackgroundResource
Service Description: Web Security Scanner Service identifies security vulnerabilities in web applications hosted on Google Cloud. It crawls your application, and attempts to exercise as many user inputs and event handlers as possible.

This class provides the ability to make remote calls to the backing service through method calls that map to API methods. Sample code to get started:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
   CreateScanConfigRequest request =
       CreateScanConfigRequest.newBuilder()
           .setParent("parent-995424086")
           .setScanConfig(ScanConfig.newBuilder().build())
           .build();
   ScanConfig response = webSecurityScannerClient.createScanConfig(request);
 }
 

Note: close() needs to be called on the WebSecurityScannerClient object to clean up resources such as threads. In the example above, try-with-resources is used, which automatically calls close().

Methods
Method Description Method Variants

CreateScanConfig

Creates a new ScanConfig.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • createScanConfig(CreateScanConfigRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • createScanConfigCallable()

DeleteScanConfig

Deletes an existing ScanConfig and its child resources.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • deleteScanConfig(DeleteScanConfigRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • deleteScanConfigCallable()

GetScanConfig

Gets a ScanConfig.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • getScanConfig(GetScanConfigRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • getScanConfigCallable()

ListScanConfigs

Lists ScanConfigs under a given project.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • listScanConfigs(ListScanConfigsRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • listScanConfigsPagedCallable()

  • listScanConfigsCallable()

UpdateScanConfig

Updates a ScanConfig. This method support partial update of a ScanConfig.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • updateScanConfig(UpdateScanConfigRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • updateScanConfigCallable()

StartScanRun

Start a ScanRun according to the given ScanConfig.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • startScanRun(StartScanRunRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • startScanRunCallable()

GetScanRun

Gets a ScanRun.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • getScanRun(GetScanRunRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • getScanRunCallable()

ListScanRuns

Lists ScanRuns under a given ScanConfig, in descending order of ScanRun stop time.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • listScanRuns(ListScanRunsRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • listScanRunsPagedCallable()

  • listScanRunsCallable()

StopScanRun

Stops a ScanRun. The stopped ScanRun is returned.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • stopScanRun(StopScanRunRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • stopScanRunCallable()

ListCrawledUrls

List CrawledUrls under a given ScanRun.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • listCrawledUrls(ListCrawledUrlsRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • listCrawledUrlsPagedCallable()

  • listCrawledUrlsCallable()

GetFinding

Gets a Finding.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • getFinding(GetFindingRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • getFindingCallable()

ListFindings

List Findings under a given ScanRun.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • listFindings(ListFindingsRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • listFindingsPagedCallable()

  • listFindingsCallable()

ListFindingTypeStats

List all FindingTypeStats under a given ScanRun.

Request object method variants only take one parameter, a request object, which must be constructed before the call.

  • listFindingTypeStats(ListFindingTypeStatsRequest request)

Callable method variants take no parameters and return an immutable API callable object, which can be used to initiate calls to the service.

  • listFindingTypeStatsCallable()

See the individual methods for example code.

Many parameters require resource names to be formatted in a particular way. To assist with these names, this class includes a format method for each type of name, and additionally a parse method to extract the individual identifiers contained within names that are returned.

This class can be customized by passing in a custom instance of WebSecurityScannerSettings to create(). For example:

To customize credentials:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 WebSecurityScannerSettings webSecurityScannerSettings =
     WebSecurityScannerSettings.newBuilder()
         .setCredentialsProvider(FixedCredentialsProvider.create(myCredentials))
         .build();
 WebSecurityScannerClient webSecurityScannerClient =
     WebSecurityScannerClient.create(webSecurityScannerSettings);
 

To customize the endpoint:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 WebSecurityScannerSettings webSecurityScannerSettings =
     WebSecurityScannerSettings.newBuilder().setEndpoint(myEndpoint).build();
 WebSecurityScannerClient webSecurityScannerClient =
     WebSecurityScannerClient.create(webSecurityScannerSettings);
 

To use REST (HTTP1.1/JSON) transport (instead of gRPC) for sending and receiving requests over the wire:


 // This snippet has been automatically generated and should be regarded as a code template only.
 // It will require modifications to work:
 // - It may require correct/in-range values for request initialization.
 // - It may require specifying regional endpoints when creating the service client as shown in
 // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
 WebSecurityScannerSettings webSecurityScannerSettings =
     WebSecurityScannerSettings.newHttpJsonBuilder().build();
 WebSecurityScannerClient webSecurityScannerClient =
     WebSecurityScannerClient.create(webSecurityScannerSettings);
 

Please refer to the GitHub repository's samples for more quickstart code snippets.

  • Constructor Details

    • WebSecurityScannerClient

      protected WebSecurityScannerClient(WebSecurityScannerSettings settings) throws IOException
      Constructs an instance of WebSecurityScannerClient, using the given settings. This is protected so that it is easy to make a subclass, but otherwise, the static factory methods should be preferred.
      Throws:
      IOException
    • WebSecurityScannerClient

      protected WebSecurityScannerClient(WebSecurityScannerStub stub)
  • Method Details

    • create

      public static final WebSecurityScannerClient create() throws IOException
      Constructs an instance of WebSecurityScannerClient with default settings.
      Throws:
      IOException
    • create

      public static final WebSecurityScannerClient create(WebSecurityScannerSettings settings) throws IOException
      Constructs an instance of WebSecurityScannerClient, using the given settings. The channels are created based on the settings passed in, or defaults for any settings that are not set.
      Throws:
      IOException
    • create

      public static final WebSecurityScannerClient create(WebSecurityScannerStub stub)
      Constructs an instance of WebSecurityScannerClient, using the given stub for making calls. This is for advanced usage - prefer using create(WebSecurityScannerSettings).
    • getSettings

      public final WebSecurityScannerSettings getSettings()
    • getStub

      public WebSecurityScannerStub getStub()
    • createScanConfig

      public final ScanConfig createScanConfig(CreateScanConfigRequest request)
      Creates a new ScanConfig.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         CreateScanConfigRequest request =
             CreateScanConfigRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setScanConfig(ScanConfig.newBuilder().build())
                 .build();
         ScanConfig response = webSecurityScannerClient.createScanConfig(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • createScanConfigCallable

      public final UnaryCallable<CreateScanConfigRequest,ScanConfig> createScanConfigCallable()
      Creates a new ScanConfig.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         CreateScanConfigRequest request =
             CreateScanConfigRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setScanConfig(ScanConfig.newBuilder().build())
                 .build();
         ApiFuture<ScanConfig> future =
             webSecurityScannerClient.createScanConfigCallable().futureCall(request);
         // Do something.
         ScanConfig response = future.get();
       }
       
    • deleteScanConfig

      public final void deleteScanConfig(DeleteScanConfigRequest request)
      Deletes an existing ScanConfig and its child resources.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         DeleteScanConfigRequest request =
             DeleteScanConfigRequest.newBuilder().setName("name3373707").build();
         webSecurityScannerClient.deleteScanConfig(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • deleteScanConfigCallable

      public final UnaryCallable<DeleteScanConfigRequest,com.google.protobuf.Empty> deleteScanConfigCallable()
      Deletes an existing ScanConfig and its child resources.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         DeleteScanConfigRequest request =
             DeleteScanConfigRequest.newBuilder().setName("name3373707").build();
         ApiFuture<Empty> future =
             webSecurityScannerClient.deleteScanConfigCallable().futureCall(request);
         // Do something.
         future.get();
       }
       
    • getScanConfig

      public final ScanConfig getScanConfig(GetScanConfigRequest request)
      Gets a ScanConfig.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         GetScanConfigRequest request =
             GetScanConfigRequest.newBuilder().setName("name3373707").build();
         ScanConfig response = webSecurityScannerClient.getScanConfig(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • getScanConfigCallable

      public final UnaryCallable<GetScanConfigRequest,ScanConfig> getScanConfigCallable()
      Gets a ScanConfig.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         GetScanConfigRequest request =
             GetScanConfigRequest.newBuilder().setName("name3373707").build();
         ApiFuture<ScanConfig> future =
             webSecurityScannerClient.getScanConfigCallable().futureCall(request);
         // Do something.
         ScanConfig response = future.get();
       }
       
    • listScanConfigs

      Lists ScanConfigs under a given project.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListScanConfigsRequest request =
             ListScanConfigsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         for (ScanConfig element : webSecurityScannerClient.listScanConfigs(request).iterateAll()) {
           // doThingsWith(element);
         }
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • listScanConfigsPagedCallable

      Lists ScanConfigs under a given project.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListScanConfigsRequest request =
             ListScanConfigsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         ApiFuture<ScanConfig> future =
             webSecurityScannerClient.listScanConfigsPagedCallable().futureCall(request);
         // Do something.
         for (ScanConfig element : future.get().iterateAll()) {
           // doThingsWith(element);
         }
       }
       
    • listScanConfigsCallable

      public final UnaryCallable<ListScanConfigsRequest,ListScanConfigsResponse> listScanConfigsCallable()
      Lists ScanConfigs under a given project.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListScanConfigsRequest request =
             ListScanConfigsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         while (true) {
           ListScanConfigsResponse response =
               webSecurityScannerClient.listScanConfigsCallable().call(request);
           for (ScanConfig element : response.getScanConfigsList()) {
             // doThingsWith(element);
           }
           String nextPageToken = response.getNextPageToken();
           if (!Strings.isNullOrEmpty(nextPageToken)) {
             request = request.toBuilder().setPageToken(nextPageToken).build();
           } else {
             break;
           }
         }
       }
       
    • updateScanConfig

      public final ScanConfig updateScanConfig(UpdateScanConfigRequest request)
      Updates a ScanConfig. This method support partial update of a ScanConfig.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         UpdateScanConfigRequest request =
             UpdateScanConfigRequest.newBuilder()
                 .setScanConfig(ScanConfig.newBuilder().build())
                 .setUpdateMask(FieldMask.newBuilder().build())
                 .build();
         ScanConfig response = webSecurityScannerClient.updateScanConfig(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • updateScanConfigCallable

      public final UnaryCallable<UpdateScanConfigRequest,ScanConfig> updateScanConfigCallable()
      Updates a ScanConfig. This method support partial update of a ScanConfig.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         UpdateScanConfigRequest request =
             UpdateScanConfigRequest.newBuilder()
                 .setScanConfig(ScanConfig.newBuilder().build())
                 .setUpdateMask(FieldMask.newBuilder().build())
                 .build();
         ApiFuture<ScanConfig> future =
             webSecurityScannerClient.updateScanConfigCallable().futureCall(request);
         // Do something.
         ScanConfig response = future.get();
       }
       
    • startScanRun

      public final ScanRun startScanRun(StartScanRunRequest request)
      Start a ScanRun according to the given ScanConfig.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         StartScanRunRequest request = StartScanRunRequest.newBuilder().setName("name3373707").build();
         ScanRun response = webSecurityScannerClient.startScanRun(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • startScanRunCallable

      public final UnaryCallable<StartScanRunRequest,ScanRun> startScanRunCallable()
      Start a ScanRun according to the given ScanConfig.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         StartScanRunRequest request = StartScanRunRequest.newBuilder().setName("name3373707").build();
         ApiFuture<ScanRun> future =
             webSecurityScannerClient.startScanRunCallable().futureCall(request);
         // Do something.
         ScanRun response = future.get();
       }
       
    • getScanRun

      public final ScanRun getScanRun(GetScanRunRequest request)
      Gets a ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         GetScanRunRequest request = GetScanRunRequest.newBuilder().setName("name3373707").build();
         ScanRun response = webSecurityScannerClient.getScanRun(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • getScanRunCallable

      public final UnaryCallable<GetScanRunRequest,ScanRun> getScanRunCallable()
      Gets a ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         GetScanRunRequest request = GetScanRunRequest.newBuilder().setName("name3373707").build();
         ApiFuture<ScanRun> future = webSecurityScannerClient.getScanRunCallable().futureCall(request);
         // Do something.
         ScanRun response = future.get();
       }
       
    • listScanRuns

      Lists ScanRuns under a given ScanConfig, in descending order of ScanRun stop time.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListScanRunsRequest request =
             ListScanRunsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         for (ScanRun element : webSecurityScannerClient.listScanRuns(request).iterateAll()) {
           // doThingsWith(element);
         }
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • listScanRunsPagedCallable

      Lists ScanRuns under a given ScanConfig, in descending order of ScanRun stop time.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListScanRunsRequest request =
             ListScanRunsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         ApiFuture<ScanRun> future =
             webSecurityScannerClient.listScanRunsPagedCallable().futureCall(request);
         // Do something.
         for (ScanRun element : future.get().iterateAll()) {
           // doThingsWith(element);
         }
       }
       
    • listScanRunsCallable

      public final UnaryCallable<ListScanRunsRequest,ListScanRunsResponse> listScanRunsCallable()
      Lists ScanRuns under a given ScanConfig, in descending order of ScanRun stop time.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListScanRunsRequest request =
             ListScanRunsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         while (true) {
           ListScanRunsResponse response =
               webSecurityScannerClient.listScanRunsCallable().call(request);
           for (ScanRun element : response.getScanRunsList()) {
             // doThingsWith(element);
           }
           String nextPageToken = response.getNextPageToken();
           if (!Strings.isNullOrEmpty(nextPageToken)) {
             request = request.toBuilder().setPageToken(nextPageToken).build();
           } else {
             break;
           }
         }
       }
       
    • stopScanRun

      public final ScanRun stopScanRun(StopScanRunRequest request)
      Stops a ScanRun. The stopped ScanRun is returned.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         StopScanRunRequest request = StopScanRunRequest.newBuilder().setName("name3373707").build();
         ScanRun response = webSecurityScannerClient.stopScanRun(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • stopScanRunCallable

      public final UnaryCallable<StopScanRunRequest,ScanRun> stopScanRunCallable()
      Stops a ScanRun. The stopped ScanRun is returned.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         StopScanRunRequest request = StopScanRunRequest.newBuilder().setName("name3373707").build();
         ApiFuture<ScanRun> future =
             webSecurityScannerClient.stopScanRunCallable().futureCall(request);
         // Do something.
         ScanRun response = future.get();
       }
       
    • listCrawledUrls

      List CrawledUrls under a given ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListCrawledUrlsRequest request =
             ListCrawledUrlsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         for (CrawledUrl element : webSecurityScannerClient.listCrawledUrls(request).iterateAll()) {
           // doThingsWith(element);
         }
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • listCrawledUrlsPagedCallable

      List CrawledUrls under a given ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListCrawledUrlsRequest request =
             ListCrawledUrlsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         ApiFuture<CrawledUrl> future =
             webSecurityScannerClient.listCrawledUrlsPagedCallable().futureCall(request);
         // Do something.
         for (CrawledUrl element : future.get().iterateAll()) {
           // doThingsWith(element);
         }
       }
       
    • listCrawledUrlsCallable

      public final UnaryCallable<ListCrawledUrlsRequest,ListCrawledUrlsResponse> listCrawledUrlsCallable()
      List CrawledUrls under a given ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListCrawledUrlsRequest request =
             ListCrawledUrlsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         while (true) {
           ListCrawledUrlsResponse response =
               webSecurityScannerClient.listCrawledUrlsCallable().call(request);
           for (CrawledUrl element : response.getCrawledUrlsList()) {
             // doThingsWith(element);
           }
           String nextPageToken = response.getNextPageToken();
           if (!Strings.isNullOrEmpty(nextPageToken)) {
             request = request.toBuilder().setPageToken(nextPageToken).build();
           } else {
             break;
           }
         }
       }
       
    • getFinding

      public final Finding getFinding(GetFindingRequest request)
      Gets a Finding.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         GetFindingRequest request = GetFindingRequest.newBuilder().setName("name3373707").build();
         Finding response = webSecurityScannerClient.getFinding(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • getFindingCallable

      public final UnaryCallable<GetFindingRequest,Finding> getFindingCallable()
      Gets a Finding.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         GetFindingRequest request = GetFindingRequest.newBuilder().setName("name3373707").build();
         ApiFuture<Finding> future = webSecurityScannerClient.getFindingCallable().futureCall(request);
         // Do something.
         Finding response = future.get();
       }
       
    • listFindings

      List Findings under a given ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListFindingsRequest request =
             ListFindingsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setFilter("filter-1274492040")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         for (Finding element : webSecurityScannerClient.listFindings(request).iterateAll()) {
           // doThingsWith(element);
         }
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • listFindingsPagedCallable

      List Findings under a given ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListFindingsRequest request =
             ListFindingsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setFilter("filter-1274492040")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         ApiFuture<Finding> future =
             webSecurityScannerClient.listFindingsPagedCallable().futureCall(request);
         // Do something.
         for (Finding element : future.get().iterateAll()) {
           // doThingsWith(element);
         }
       }
       
    • listFindingsCallable

      public final UnaryCallable<ListFindingsRequest,ListFindingsResponse> listFindingsCallable()
      List Findings under a given ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListFindingsRequest request =
             ListFindingsRequest.newBuilder()
                 .setParent("parent-995424086")
                 .setFilter("filter-1274492040")
                 .setPageToken("pageToken873572522")
                 .setPageSize(883849137)
                 .build();
         while (true) {
           ListFindingsResponse response =
               webSecurityScannerClient.listFindingsCallable().call(request);
           for (Finding element : response.getFindingsList()) {
             // doThingsWith(element);
           }
           String nextPageToken = response.getNextPageToken();
           if (!Strings.isNullOrEmpty(nextPageToken)) {
             request = request.toBuilder().setPageToken(nextPageToken).build();
           } else {
             break;
           }
         }
       }
       
    • listFindingTypeStats

      public final ListFindingTypeStatsResponse listFindingTypeStats(ListFindingTypeStatsRequest request)
      List all FindingTypeStats under a given ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListFindingTypeStatsRequest request =
             ListFindingTypeStatsRequest.newBuilder().setParent("parent-995424086").build();
         ListFindingTypeStatsResponse response =
             webSecurityScannerClient.listFindingTypeStats(request);
       }
       
      Parameters:
      request - The request object containing all of the parameters for the API call.
      Throws:
      ApiException - if the remote call fails
    • listFindingTypeStatsCallable

      public final UnaryCallable<ListFindingTypeStatsRequest,ListFindingTypeStatsResponse> listFindingTypeStatsCallable()
      List all FindingTypeStats under a given ScanRun.

      Sample code:

      
       // This snippet has been automatically generated and should be regarded as a code template only.
       // It will require modifications to work:
       // - It may require correct/in-range values for request initialization.
       // - It may require specifying regional endpoints when creating the service client as shown in
       // https://cloud.google.com/java/docs/setup#configure_endpoints_for_the_client_library
       try (WebSecurityScannerClient webSecurityScannerClient = WebSecurityScannerClient.create()) {
         ListFindingTypeStatsRequest request =
             ListFindingTypeStatsRequest.newBuilder().setParent("parent-995424086").build();
         ApiFuture<ListFindingTypeStatsResponse> future =
             webSecurityScannerClient.listFindingTypeStatsCallable().futureCall(request);
         // Do something.
         ListFindingTypeStatsResponse response = future.get();
       }
       
    • close

      public final void close()
      Specified by:
      close in interface AutoCloseable
    • shutdown

      public void shutdown()
      Specified by:
      shutdown in interface BackgroundResource
    • isShutdown

      public boolean isShutdown()
      Specified by:
      isShutdown in interface BackgroundResource
    • isTerminated

      public boolean isTerminated()
      Specified by:
      isTerminated in interface BackgroundResource
    • shutdownNow

      public void shutdownNow()
      Specified by:
      shutdownNow in interface BackgroundResource
    • awaitTermination

      public boolean awaitTermination(long duration, TimeUnit unit) throws InterruptedException
      Specified by:
      awaitTermination in interface BackgroundResource
      Throws:
      InterruptedException