Uses of Class
com.google.cloud.websecurityscanner.v1.WebSecurityScannerClient.ListScanRunsPagedResponse
Packages that use WebSecurityScannerClient.ListScanRunsPagedResponse
Package
Description
A client to Web Security Scanner API
-
Uses of WebSecurityScannerClient.ListScanRunsPagedResponse in com.google.cloud.websecurityscanner.v1
Methods in com.google.cloud.websecurityscanner.v1 that return WebSecurityScannerClient.ListScanRunsPagedResponseModifier and TypeMethodDescriptionWebSecurityScannerClient.listScanRuns(ListScanRunsRequest request) Lists ScanRuns under a given ScanConfig, in descending order of ScanRun stop time.Methods in com.google.cloud.websecurityscanner.v1 that return types with arguments of type WebSecurityScannerClient.ListScanRunsPagedResponseModifier and TypeMethodDescriptionWebSecurityScannerClient.ListScanRunsPagedResponse.createAsync(PageContext<ListScanRunsRequest, ListScanRunsResponse, ScanRun> context, ApiFuture<ListScanRunsResponse> futureResponse) WebSecurityScannerClient.listScanRunsPagedCallable()Lists ScanRuns under a given ScanConfig, in descending order of ScanRun stop time.PagedCallSettings.Builder<ListScanRunsRequest,ListScanRunsResponse, WebSecurityScannerClient.ListScanRunsPagedResponse> WebSecurityScannerSettings.Builder.listScanRunsSettings()Returns the builder for the settings used for calls to listScanRuns.PagedCallSettings<ListScanRunsRequest,ListScanRunsResponse, WebSecurityScannerClient.ListScanRunsPagedResponse> WebSecurityScannerSettings.listScanRunsSettings()Returns the object with the settings used for calls to listScanRuns. -
Uses of WebSecurityScannerClient.ListScanRunsPagedResponse in com.google.cloud.websecurityscanner.v1.stub
Methods in com.google.cloud.websecurityscanner.v1.stub that return types with arguments of type WebSecurityScannerClient.ListScanRunsPagedResponseModifier and TypeMethodDescriptionGrpcWebSecurityScannerStub.listScanRunsPagedCallable()HttpJsonWebSecurityScannerStub.listScanRunsPagedCallable()WebSecurityScannerStub.listScanRunsPagedCallable()PagedCallSettings.Builder<ListScanRunsRequest,ListScanRunsResponse, WebSecurityScannerClient.ListScanRunsPagedResponse> WebSecurityScannerStubSettings.Builder.listScanRunsSettings()Returns the builder for the settings used for calls to listScanRuns.PagedCallSettings<ListScanRunsRequest,ListScanRunsResponse, WebSecurityScannerClient.ListScanRunsPagedResponse> WebSecurityScannerStubSettings.listScanRunsSettings()Returns the object with the settings used for calls to listScanRuns.